import { getNewsClassList, getNewsList } from '@/api/news'
function getImages(modules) {
    return Object.keys(modules).map(key => modules[key].default)
}
export function useIndex(platform) {
    const swiperOptions = {
        slidesPerView: 1,
        spaceBetween: 30,
        loop: true,
        centeredSlides: true,
        autoplay: {
            delay: 3500,
            disableOnInteraction: false,
        },
    }
    let coverModules = null,
        newModules = null,
        roleModules = null,
        roleIconModules = null,
        roleDescModules = null,
        posterModules = null
    if (platform === 'pc') {
        coverModules = import.meta.globEager('../../assets/images/p/cover_swiper/*.jpg')
        newModules = import.meta.globEager('../../assets/images/p/new_swiper/*.png')
        roleModules = import.meta.globEager('../../assets/images/p/role_swiper/*.png')
        roleIconModules = import.meta.globEager('../../assets/images/p/role_icon/*.png')
        posterModules = import.meta.globEager('../../assets/images/p/poster_swiper/*.jpg')
    } else {
        coverModules = import.meta.globEager('../../assets/images/m/cover_swiper/*.jpg')
        newModules = import.meta.globEager('../../assets/images/m/new_swiper/*.png')
        roleModules = import.meta.globEager('../../assets/images/m/role_swiper/*.png')
        roleIconModules = import.meta.globEager('../../assets/images/m/role_icon/*.png')
        roleDescModules = import.meta.globEager('../../assets/images/m/role_desc/*.png')
        posterModules = import.meta.globEager('../../assets/images/m/poster_swiper/*.jpg')
    }
    // 封面
    const coverThumb = getImages(coverModules)

    // 新闻
    const newThumb = getImages(newModules)

    // 角色
    const roleThumb = getImages(roleModules)

    // 角色图标
    const roleIconThumb = getImages(roleIconModules)

    // 角色描述
    const roleDescThumb = roleDescModules ? getImages(roleDescModules) : []

    // 海报
    const posterThumb = getImages(posterModules)

    // 封面swiper实例
    const swiperCover = ref(null)
    // 选中的封面
    const activeCover = ref(0)
    // 角色swiper实例
    const swiperRole = ref(null)
    // 选中的角色
    const activeRole = ref(0)
    // 新闻分页
    const page = ref({
        page: 1,
        page_size: 20,
    })
    // 新闻分类
    const classId = ref('')
    // 新闻列表
    const newList = ref([])
    // 是否加载完成
    const newsFinished = ref(false)
    // 获取封面swiper实例
    function onSwiperCover(swiper) {
        swiperCover.value = swiper
    }
    // 切换封面图触发
    function changeCover(swiper) {
        activeCover.value = swiper.realIndex
    }
    // 手动切换封面图
    function slideCover(index) {
        swiperCover.value.slideTo(index + 1)
    }
    // 获取角色iocn样式
    function getRoleStyle(index) {
        if (activeRole.value !== index) return 'filter: grayscale(100%);'
        return ''
    }
    // 获取角色swiper实例
    function onSwiperRole(swiper) {
        swiperRole.value = swiper
    }
    // 切换角色图触发
    function changeRole(swiper) {
        activeRole.value = swiper.realIndex
    }
    // 手动切换角色图
    function slideRole(index) {
        swiperRole.value.slideTo(index + 1)
    }
    // 初始化新闻列表
    async function getInitNews() {
        try {
            const classRes = await getNewsClassList({
                class_type: 0,
            })
            const { code, data } = classRes
            if (code !== 0 || !data.news_class_list || !data.news_class_list.length) return
            classId.value = data.news_class_list[0].id
            const params = {
                class_id: classId.value,
                ...page.value,
            }
            const newRes = await getNewsList(params)
            newList.value = newRes.code === 0 ? newRes?.data?.news_list || [] : []
            checkNewsFinished(newRes.data || {})
        } catch (error) {}
    }
    // 获取新闻列表
    function getNews() {
        page.value.page++
        const params = {
            class_id: classId.value,
            ...page.value,
        }
        getNewsList(params).then(({ code, data }) => {
            if (code !== 0) return
            newList.value = [...newList.value, ...data.news_list]
            checkNewsFinished(data || {})
        })
    }
    // 判断新闻是否加载完成
    function checkNewsFinished(data) {
        if (data.count < page.value.page_size || newList.value.length === data.count) {
            newsFinished.value = true
        }
    }
    getInitNews()
    return {
        swiperOptions,
        coverThumb,
        newThumb,
        roleThumb,
        roleIconThumb,
        roleDescThumb,
        posterThumb,
        swiperCover,
        activeCover,
        swiperRole,
        activeRole,
        changeCover,
        onSwiperCover,
        slideCover,
        getRoleStyle,
        changeRole,
        onSwiperRole,
        slideRole,
        getNews,
        newList,
        newsFinished,
    }
}
