import { nextTick, createVNode } from 'vue'
import { useMountComponent } from '@/utils/useMountComponent'
import ToastConstructor from '@/components/toast/index.vue'

const toast = options => {
    const duration = typeof options !== 'string' ? options.duration : 3000
    const { instance, unmount } = useMountComponent(
        createVNode(ToastConstructor, {
            message: typeof options === 'string' ? options : options.message,
        })
    )

    // 获取实例的代理和data 代理可以拿到dom对象 data可以设置state
    const { proxy, data } = instance.$
    const RemoveSelf = function (event) {
        unmount()
    }

    // 在toast实例挂载到dom上之后执行 展示与消失
    nextTick(() => {
        data.visible = true
        proxy?.$el.removeEventListener('transitionend', RemoveSelf)
        ~duration &&
            setTimeout(function () {
                data.visible = false
                proxy?.$el.addEventListener('transitionend', RemoveSelf)
            }, duration)
    })
    return instance
}

export default {
    // 挂载对象需要提供 install方法
    install: app => {
        app.config.globalProperties.$toast = toast
        window.$toast = toast
    },
}
