function originalClipboard(value, resolve, reject) {
    try {
        const span = document.createElement('span')
        span.textContent = value
        span.style.whiteSpace = 'pre'
        span.style.webkitUserSelect = 'auto'
        span.style.userSelect = 'all'
        document.body.appendChild(span)
        const selection = getSelection()
        const range = document.createRange()
        selection.removeAllRanges()
        range.selectNode(span)
        selection.addRange(range)
        const result = document.execCommand('copy')
        console.log('execCommand ', result)
        if (result) {
            resolve()
        } else {
            reject(false)
        }
        document.body.removeChild(span)
    } catch (error) {
        console.log('error-----', error)
        reject(false)
    }
}

export const isAndroid = navigator.userAgent.indexOf('Android') > -1

export const isIos = /(iPhone|iPad|iPod|iOS|Mac OS)/i.test(navigator.userAgent)

export function getOs() {
    if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
        return 1
    } else if (/(Android)/i.test(navigator.userAgent)) {
        return 2
    } else {
        return 4
    }
}

export function getAssetsFile(url) {
    return new URL(`../assets/images${url}`, import.meta.url).href
}

export function getQueryObject(url) {
    url = url == null ? window.location.href : url
    const search = url.substring(url.lastIndexOf('?') + 1)
    const obj = {}
    const reg = /([^?&=]+)=([^?&=#]*)/g
    search.replace(reg, (rs, $1, $2) => {
        const name = decodeURIComponent($1)
        let val = decodeURIComponent($2)
        val = String(val)
        obj[name] = val
        return rs
    })
    return obj
}

export function formatDate(millisecond, template = 'YYYY-mm-dd') {
    var res = ''
    try {
        var date = new Date(millisecond)
        var opt = {
            'Y+': date.getFullYear().toString(), // 年
            'm+': (date.getMonth() + 1).toString(), // 月
            'd+': date.getDate().toString(), // 日
            'H+': date.getHours().toString(), // 时
            'M+': date.getMinutes().toString(), // 分
            'S+': date.getSeconds().toString(), // 秒
        }
        template = template || 'YYYY-mm-dd'
        for (var k in opt) {
            var ret = new RegExp('(' + k + ')').exec(template)
            if (ret) {
                template = template.replace(ret[1], ret[1].length == 1 ? opt[k] : opt[k].padStart(ret[1].length, '0'))
            }
        }
        res = template
    } catch (error) {
        console.warn('ERROR formatDate', error)
    }
    return res
}

export function formatNumber(num) {
    return num >= 1e3 && num < 1e4 ? (num / 1e3).toFixed(1) + 'k' : num >= 1e4 ? (num / 1e4).toFixed(1) + 'w' : num
}

export function copyToClipboard(value) {
    return new Promise((resolve, reject) => {
        if (!value) return reject(false)
        const clipboard = navigator.clipboard // 安全域包括本地访问与开启TLS安全认证的地址，如 https 协议的地址、127.0.0.1 或 localhost
        // navigator clipboard 需要https等安全上下文
        if (clipboard && window.isSecureContext) {
            clipboard.writeText(value).then(
                () => {
                    resolve()
                },
                err => {
                    originalClipboard(value, resolve, reject)
                }
            )
        } else {
            originalClipboard(value, resolve, reject)
        }
    })
}

// 防抖动函数
export function debounce(func, wait, immediate) {
    var timeout
    return function () {
        var context = this,
            args = arguments
        var later = function () {
            timeout = null
            if (!immediate) func.apply(context, args)
        }
        var callNow = immediate && !timeout
        clearTimeout(timeout)
        timeout = setTimeout(later, wait)
        if (callNow) func.apply(context, args)
    }
}

// 节流函数
export function throttle(func, wait, mustRun) {
    var timeout,
        startTime = new Date()

    return function () {
        var context = this,
            args = arguments,
            curTime = new Date()

        clearTimeout(timeout)
        // 如果达到了规定的触发时间间隔，触发 handler
        if (curTime - startTime >= mustRun) {
            func.apply(context, args)
            startTime = curTime
            // 没达到触发间隔，重新设定定时器
        } else {
            timeout = setTimeout(func, wait)
        }
    }
}
