import axios from 'axios'
import { getOs, getQueryObject } from '@/utils'
const query = getQueryObject()

const commonData = {
    game_id: 13,
    system_area_code: code,
    system_lang_code: 'zh-hant',
    os: getOs(),
    channel: query.channel || '',
    campaign: query.campaign || '',
    charge_uid: query.charge_uid || '',
}

export const request = axios.create({
    baseURL: import.meta.env.VITE_APP_BASE_API,
    timeout: 10000,
    headers: {
        'content-type': 'application/json',
    },
})

request.interceptors.request.use(config => {
    config.data = {
        ...config.data,
        ...commonData,
    }
    // 接口不允许值为null，如果为null，转为空串
    if (typeof config.data === 'object') {
        for (const v in config.data) {
            if (config.data[v] === null || config.data[v] === undefined) {
                config.data[v] = ''
            }
        }
    }

    return config
})

request.interceptors.response.use(response => {
    const res = response.data
    if (res.code !== 0) {
        return Promise.reject(new Error(res.message || 'Error'))
    }
    return res
})
