import { defineConfig, loadEnv } from 'vite'
import path from 'path'
import vue from '@vitejs/plugin-vue'
import { createHtmlPlugin } from 'vite-plugin-html'
// 支持 setup name
import VueSetupExtend from 'vite-plugin-vue-setup-extend'
// 自动导入组件
import Components from 'unplugin-vue-components/vite'
// 自动导入API，如：vue的ref,reactive等，vue-router的useRoute等
import AutoImport from 'unplugin-auto-import/vite'
// 像素打点
import { facebookPixelBodyInject, googlePixelBodyInject, googlePixelHeadInject, tiktokPixelInject, twitterPixelInject } from './pixelInject'

const resolve = dir => {
    return path.join(__dirname, dir)
}
export default ({ mode, command }) => {
    // 拓展process.env
    const env = loadEnv(mode, process.cwd())
    const port = env.VITE_APP_PORT || process.env.port || 8888

    return defineConfig({
        // 开发或生产环境服务的公共基础路，相当于 vue-cli 的 public
        base: '/',
        plugins: [
            vue(),
            VueSetupExtend(),
            AutoImport({
                imports: ['vue', 'vue-router'],
                dts: 'src/auto-imports.d.ts', // 生成auto-imports.d.ts全局声明
            }),
            Components({
                extensions: ['vue'],
                include: [/\.vue$/, /\.vue\?vue/],
                directoryAsNamespace: true, // 允许子目录作为组件的命名空间前缀
                dts: 'src/components.d.ts',
            }),
            createHtmlPlugin({
                // 是否压缩 html
                minify: true,
                // 在这里写entry后，你将不需要在`index.html`内添加 script 标签，原有标签需要删除
                entry: 'src/main.js',
                // 如果你想将 `index.html`存放在指定文件夹，可以修改它，否则不需要配置
                // template: 'public/index.html',
                // 需要注入 index.html ejs 模版的数据
                inject: {
                    data: {
                        title: env.VITE_APP_TITLE,
                        injectHeadScript: [googlePixelHeadInject(env)].join(''),
                        injectBodyScript: [googlePixelBodyInject(env), facebookPixelBodyInject(env), tiktokPixelInject(env), twitterPixelInject(env)].join(''),
                    },
                },
            }),
        ],
        // 配置路径别名
        resolve: {
            alias: {
                '@': resolve('src'),
            },
        },
        // 提供全局 scss 变量
        css: {
            preprocessorOptions: {
                scss: {
                    additionalData: `
                @import "@/styles/index";`,
                },
            },
        },
        // 开发服务器选项
        server: {
            port,
            host: true,
            open: false,
            hmr: true,              // 热更新配置
            // watch: {
            //     usePolling: true   // Windows Linux 子系统（WSL）必须，否则热更新无效（usePolling 会导致高 CPU 占用率）
            // }
        },
    })
}
